@@ -69,7 +69,7 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection, const
     qCDebug(PLASMA_NM) << "Flags:" << flags;
 
     const QString callId = connection_path.path() % setting_name;
-    Q_FOREACH(const SecretsRequest & request, m_calls) {
+    Q_FOREACH (const SecretsRequest & request, m_calls) {
         if (request == callId) {
             qCWarning(PLASMA_NM) << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
             CancelGetSecrets(connection_path, setting_name);
@@ -229,7 +229,7 @@ void SecretAgent::dialogAccepted()
                     }
 
                     // Load temporary secrets from auth dialog which are not returned to NM
-                    Q_FOREACH(const QString &key, tmpOpenconnectSecrets.keys()) {
+                    Q_FOREACH (const QString &key, tmpOpenconnectSecrets.keys()) {
                         if (secrets.contains(QLatin1Literal("save_passwords")) && secrets.value(QLatin1Literal("save_passwords")) == QLatin1String("yes")) {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
                         } else {
@@ -373,19 +373,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     }
 
     if (!secretsMap.isEmpty()) {
-        // FIXME workaround just for Plasma 5.2 for a missing fix in networkmanager-qt
-        if (isVpn) {
-            NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
-            if (vpnSetting) {
-                NMStringMap secrets = vpnSetting->secrets();
-                vpnSetting->secretsFromStringMap(secretsMap);
-                secrets.unite(vpnSetting->secrets());
-                vpnSetting->setSecrets(secrets);
-            }
-        } else {
-            setting->secretsFromStringMap(secretsMap);
-        }
-
+        setting->secretsFromStringMap(secretsMap);
         if (!isVpn && setting->needSecrets(requestNew).isEmpty()) {
             // Enough secrets were retrieved from storage
             request.connection[request.setting_name] = setting->secretsToMap();
@@ -460,7 +448,7 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
             }
 
             if (m_wallet->setFolder("Network Management")) {
-                Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
                     NMStringMap secretsMap = setting->secretsToStringMap();
 
                     if (!secretsMap.isEmpty()) {
@@ -496,9 +484,9 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
         if (m_wallet->isOpen()) {
             if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
                 NetworkManager::ConnectionSettings connectionSettings(request.connection);
-                Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+                Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
                     QString entryName = QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name();
-                    Q_FOREACH(const QString &entry, m_wallet->entryList()) {
+                    Q_FOREACH (const QString &entry, m_wallet->entryList()) {
                         if (entry.startsWith(entryName)) {
                             m_wallet->removeEntry(entryName);
                         }
@@ -552,7 +540,7 @@ bool SecretAgent::useWallet() const
 bool SecretAgent::hasSecrets(const NMVariantMapMap &connection) const
 {
     NetworkManager::ConnectionSettings connectionSettings(connection);
-    Q_FOREACH(const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
+    Q_FOREACH (const NetworkManager::Setting::Ptr &setting, connectionSettings.settings()) {
         if (!setting->secretsToMap().isEmpty()) {
             return true;
         }
@@ -576,7 +564,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
 
     // No action is required when the list of secrets is empty
     if (!config.groupList().isEmpty()) {
-        Q_FOREACH(const QString &groupName, config.groupList()) {
+        Q_FOREACH (const QString &groupName, config.groupList()) {
             QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
             QString loadedSettingType = groupName.split(';').last();
             NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
@@ -585,7 +573,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                 QMap<QString, QString> secrets = config.entryMap(groupName);
                 NMVariantMapMap settings = connection->settings()->toMap();
 
-                Q_FOREACH(const QString &setting, settings.keys()) {
+                Q_FOREACH (const QString &setting, settings.keys()) {
                     if (setting == QLatin1String("vpn")) {
                         NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).staticCast<NetworkManager::VpnSetting>();
                         if (vpnSetting) {
@@ -595,7 +583,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             NMStringMap vpnData = vpnSetting->data();
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            Q_FOREACH(const QString &key, vpnData.keys()) {
+                            Q_FOREACH (const QString &key, vpnData.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     vpnData.insert(key, QString::number((int)secretFlags));
                                 }
@@ -610,7 +598,7 @@ void SecretAgent::importSecretsFromPlainTextFiles()
                             QVariantMap tmpSetting = settings.value(setting);
                             // Reset flags, we can't save secrets to our secret agent when KWallet is not enabled, because
                             // we dropped support for plaintext files, therefore they need to be stored to NetworkManager
-                            Q_FOREACH(const QString &key, tmpSetting.keys()) {
+                            Q_FOREACH (const QString &key, tmpSetting.keys()) {
                                 if (key.endsWith(QLatin1String("-flags"))) {
                                     tmpSetting.insert(key, (int)secretFlags);
                                 }
