@@ -21,7 +21,7 @@
 #ifndef PLASMA_NM_BT_WIDGET_H
 #define PLASMA_NM_BT_WIDGET_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 #include <NetworkManagerQt/BluetoothSetting>
 
@@ -39,11 +39,11 @@ public:
     explicit BtWidget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget* parent = 0, Qt::WindowFlags f = 0);
     virtual ~BtWidget();
 
-    void loadConfig(const NetworkManager::Setting::Ptr &setting);
+    void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const;
+    QVariantMap setting(bool agentOwned = false) const Q_DECL_OVERRIDE;
 
-    virtual bool isValid() const;
+    virtual bool isValid() const Q_DECL_OVERRIDE;
 
 private:
     Ui::BtWidget * m_ui;
